# Contributors

AMSET development is led by the Hacking Materials research group led by
Anubhav Jain at Lawrence Berkeley National Lab, using primarily research funding
from U.S. Department of Energy Early Career program.

Alex Ganose is the primary developer.

Other contributions are provided by:

* Junsoo Park and Alireza Faghaninia through the research group of A. Jain at LBNL.
* Francesco Ricci through the research group of Prof. Geoffroy Hautier at UC Louvain
* Jason Frost
